pub struct InventoryCustomBatchResponseEntry {
pub batch_id: Option<u32>,
pub errors: Option<Errors>,
pub kind: Option<String>,
}Expand description
A batch entry encoding a single non-batch inventory response.
This type is not used in any activity, and only used as part of another schema.
Fields
batch_id: Option<u32>The ID of the request entry this entry responds to.
errors: Option<Errors>A list of errors defined if and only if the request failed.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “content#inventoryCustomBatchResponseEntry”