pub struct LiasettingsCustomBatchResponse {
pub entries: Option<Vec<LiasettingsCustomBatchResponseEntry>>,
pub kind: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- custombatch liasettings (response)
Fields
entries: Option<Vec<LiasettingsCustomBatchResponseEntry>>The result of the execution of the batch requests.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “content#liasettingsCustomBatchResponse”.