pub struct OrderLegacyPromotionBenefit {
pub discount: Option<Price>,
pub offer_ids: Option<Vec<String>>,
pub sub_type: Option<String>,
pub tax_impact: Option<Price>,
pub type_: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
discount: Option<Price>The discount in the order price when the promotion is applied.
offer_ids: Option<Vec<String>>The OfferId(s) that were purchased in this order and map to this specific benefit of the promotion.
sub_type: Option<String>Further describes the benefit of the promotion. Note that we will expand on this enumeration as we support new promotion sub-types. Acceptable values are: - “buyMGetMoneyOff” - “buyMGetNMoneyOff” - “buyMGetNPercentOff” - “buyMGetPercentOff” - “freeGift” - “freeGiftWithItemId” - “freeGiftWithValue” - “freeOvernightShipping” - “freeShipping” - “freeTwoDayShipping” - “moneyOff” - “percentageOff” - “rewardPoints” - “salePrice”
tax_impact: Option<Price>The impact on tax when the promotion is applied.
type_: Option<String>Describes whether the promotion applies to products (e.g. 20% off) or to shipping (e.g. Free Shipping). Acceptable values are: - “product” - “shipping”