pub struct OrdersReturnRefundLineItemRequest {
pub amount_pretax: Option<Price>,
pub amount_tax: Option<Price>,
pub line_item_id: Option<String>,
pub operation_id: Option<String>,
pub product_id: Option<String>,
pub quantity: Option<u32>,
pub reason: Option<String>,
pub reason_text: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- returnrefundlineitem orders (request)
Fields
amount_pretax: Option<Price>The amount that is refunded. If omitted, refundless return is assumed (same as calling returnLineItem method).
amount_tax: Option<Price>Tax amount that corresponds to refund amount in amountPretax. Optional, but if filled, then amountPretax must be set. Calculated automatically if not provided.
line_item_id: Option<String>The ID of the line item to return. Either lineItemId or productId is required.
operation_id: Option<String>The ID of the operation. Unique across all operations for a given order.
product_id: Option<String>The ID of the product to return. This is the REST ID used in the products service. Either lineItemId or productId is required.
quantity: Option<u32>The quantity to return and refund. Quantity is required.
reason: Option<String>The reason for the return. Acceptable values are: - “customerDiscretionaryReturn” - “customerInitiatedMerchantCancel” - “deliveredTooLate” - “expiredItem” - “invalidCoupon” - “malformedShippingAddress” - “other” - “productArrivedDamaged” - “productNotAsDescribed” - “qualityNotAsExpected” - “undeliverableShippingAddress” - “unsupportedPoBoxAddress” - “wrongProductShipped”
reason_text: Option<String>The explanation of the reason.