pub struct PosSale {
pub content_language: Option<String>,
pub gtin: Option<String>,
pub item_id: Option<String>,
pub kind: Option<String>,
pub price: Option<Price>,
pub quantity: Option<i64>,
pub sale_id: Option<String>,
pub store_code: Option<String>,
pub target_country: Option<String>,
pub timestamp: Option<String>,
}Expand description
The change of the available quantity of an item at the given store.
This type is not used in any activity, and only used as part of another schema.
Fields
content_language: Option<String>Required. The two-letter ISO 639-1 language code for the item.
gtin: Option<String>Global Trade Item Number.
item_id: Option<String>Required. A unique identifier for the item.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “content#posSale”
price: Option<Price>Required. The price of the item.
quantity: Option<i64>Required. The relative change of the available quantity. Negative for items returned.
sale_id: Option<String>A unique ID to group items from the same sale event.
store_code: Option<String>Required. The identifier of the merchant’s store. Either a storeCode inserted via the API or the code of the store in Google My Business.
target_country: Option<String>Required. The CLDR territory code for the item.
timestamp: Option<String>Required. The inventory timestamp, in ISO 8601 format.