pub struct ProductstatusesListResponse {
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub resources: Option<Vec<ProductStatus>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list productstatuses (response)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “content#productstatusesListResponse”.
next_page_token: Option<String>The token for the retrieval of the next page of products statuses.
resources: Option<Vec<ProductStatus>>no description provided