Struct google_content2::AccountStatus
[−]
[src]
pub struct AccountStatus {
pub kind: Option<String>,
pub website_claimed: Option<bool>,
pub data_quality_issues: Option<Vec<AccountStatusDataQualityIssue>>,
pub account_id: Option<String>,
}The status of an account, i.e., information about its products, which is computed offline and not returned immediately at insertion time.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get accountstatuses (response)
Fields
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "content#accountStatus".
website_claimed: Option<bool>
Whether the account's website is claimed or not.
data_quality_issues: Option<Vec<AccountStatusDataQualityIssue>>
A list of data quality issues.
account_id: Option<String>
The ID of the account for which the status is reported.