Struct google_content2::OrderpaymentsNotifyRefundResponse [−][src]
pub struct OrderpaymentsNotifyRefundResponse {
pub kind: Option<String>,
pub execution_status: Option<String>,
}There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notifyrefund orderpayments (response)
Fields
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "content#orderpaymentsNotifyRefundResponse".
execution_status: Option<String>
The status of the execution.