Struct google_content2::OrderreturnsListResponse [−][src]
pub struct OrderreturnsListResponse {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub resources: Option<Vec<MerchantOrderReturn>>,
}There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list orderreturns (response)
Fields
next_page_token: Option<String>
The token for the retrieval of the next page of returns.
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "content#orderreturnsListResponse".
resources: Option<Vec<MerchantOrderReturn>>
no description provided