pub struct OrdersCustomBatchRequestEntryCancelLineItem {
    pub amount: Option<Price>,
    pub amount_pretax: Option<Price>,
    pub reason_text: Option<String>,
    pub line_item_id: Option<String>,
    pub reason: Option<String>,
    pub amount_tax: Option<Price>,
    pub quantity: Option<u32>,
    pub product_id: Option<String>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

amount: Option<Price>

Deprecated. Please use amountPretax and amountTax instead.

amount_pretax: Option<Price>

Amount to refund for the cancelation. Optional. If not set, Google will calculate the default based on the price and tax of the items involved. The amount must not be larger than the net amount left on the order.

reason_text: Option<String>

The explanation of the reason.

line_item_id: Option<String>

The ID of the line item to cancel. Either lineItemId or productId is required.

reason: Option<String>

The reason for the cancellation.

amount_tax: Option<Price>

Tax amount that correspond to cancellation amount in amountPretax.

quantity: Option<u32>

The quantity to cancel.

product_id: Option<String>

The ID of the product to cancel. This is the REST ID used in the products service. Either lineItemId or productId is required.