pub struct OrdersCustomBatchRequestEntryRefund {
pub reason: Option<String>,
pub amount: Option<Price>,
pub reason_text: Option<String>,
pub amount_tax: Option<Price>,
pub amount_pretax: Option<Price>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
reason: Option<String>The reason for the refund.
amount: Option<Price>Deprecated. Please use amountPretax and amountTax instead.
reason_text: Option<String>The explanation of the reason.
amount_tax: Option<Price>Tax amount that correspond to refund amount in amountPretax.
amount_pretax: Option<Price>The amount that is refunded. Either amount or amountPretax and amountTax should be filled.