pub struct OrdersCustomBatchRequestEntryReturnRefundLineItem {
    pub amount_pretax: Option<Price>,
    pub reason_text: Option<String>,
    pub line_item_id: Option<String>,
    pub amount_tax: Option<Price>,
    pub quantity: Option<u32>,
    pub reason: Option<String>,
    pub product_id: Option<String>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

amount_pretax: Option<Price>

The amount that is refunded. If omitted, refundless return is assumed (same as calling returnLineItem method). Optional, but if filled then both amountPretax and amountTax must be set.

reason_text: Option<String>

The explanation of the reason.

line_item_id: Option<String>

The ID of the line item to return. Either lineItemId or productId is required.

amount_tax: Option<Price>

Tax amount that correspond to refund amount in amountPretax.

quantity: Option<u32>

The quantity to return and refund.

reason: Option<String>

The reason for the return.

product_id: Option<String>

The ID of the product to return. This is the REST ID used in the products service. Either lineItemId or productId is required.