pub struct OrdersCustomBatchRequestEntryUpdateLineItemShippingDetails {
pub deliver_by_date: Option<String>,
pub product_id: Option<String>,
pub line_item_id: Option<String>,
pub ship_by_date: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
deliver_by_date: Option<String>Updated delivery by date, in ISO 8601 format. If not specified only ship by date is updated.
product_id: Option<String>The ID of the product to set metadata. This is the REST ID used in the products service. Either lineItemId or productId is required.
line_item_id: Option<String>The ID of the line item to set metadata. Either lineItemId or productId is required.
ship_by_date: Option<String>Updated ship by date, in ISO 8601 format. If not specified only deliver by date is updated.