Struct google_content2::ProductstatusesCustomBatchResponse [−][src]
pub struct ProductstatusesCustomBatchResponse {
pub kind: Option<String>,
pub entries: Option<Vec<ProductstatusesCustomBatchResponseEntry>>,
}There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- custombatch productstatuses (response)
Fields
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "content#productstatusesCustomBatchResponse".
entries: Option<Vec<ProductstatusesCustomBatchResponseEntry>>
The result of the execution of the batch requests.